package com.zehong.system.service.impl.track;

import java.util.List;
import com.zehong.common.utils.DateUtils;
import com.zehong.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zehong.system.mapper.track.TProductMarkMapper;
import com.zehong.system.domain.track.TProductMark;
import com.zehong.system.service.track.ITProductMarkService;

/**
 * 装配模板Service业务层处理
 * 
 * @author zehong
 * @date 2024-08-23
 */
@Service
public class TProductMarkServiceImpl implements ITProductMarkService 
{
    @Autowired
    private TProductMarkMapper tProductMarkMapper;

    /**
     * 查询装配模板
     * 
     * @param id 装配模板ID
     * @return 装配模板
     */
    @Override
    public TProductMark selectTProductMarkById(Long id)
    {
        return tProductMarkMapper.selectTProductMarkById(id);
    }

    /**
     * 查询装配模板列表
     * 
     * @param tProductMark 装配模板
     * @return 装配模板
     */
    @Override
    public List<TProductMark> selectTProductMarkList(TProductMark tProductMark)
    {
        return tProductMarkMapper.selectTProductMarkList(tProductMark);
    }

    /**
     * 新增装配模板
     * 
     * @param tProductMark 装配模板
     * @return 结果
     */
    @Override
    public int insertTProductMark(TProductMark tProductMark)
    {
        tProductMark.setCreateTime(DateUtils.getNowDate());
        tProductMark.setCreateId(SecurityUtils.getLoginUser().getUser().getUserId());
        return tProductMarkMapper.insertTProductMark(tProductMark);
    }

    /**
     * 修改装配模板
     * 
     * @param tProductMark 装配模板
     * @return 结果
     */
    @Override
    public int updateTProductMark(TProductMark tProductMark)
    {
        return tProductMarkMapper.updateTProductMark(tProductMark);
    }

    /**
     * 批量删除装配模板
     * 
     * @param ids 需要删除的装配模板ID
     * @return 结果
     */
    @Override
    public int deleteTProductMarkByIds(Long[] ids)
    {
        return tProductMarkMapper.deleteTProductMarkByIds(ids);
    }

    /**
     * 删除装配模板信息
     * 
     * @param id 装配模板ID
     * @return 结果
     */
    @Override
    public int deleteTProductMarkById(Long id)
    {
        return tProductMarkMapper.deleteTProductMarkById(id);
    }
}
